@@ -375,8 +375,11 @@ class ObjectClerk:
             f"destination_object_key={destination_object_key}"
         )
         copy_source = {"Bucket": source_bucket, "Key": source_object_key}
-        self.client.copy_object(
-            Bucket=destination_bucket, Key=destination_object_key, CopySource=copy_source
+        self.client.copy(
+            Bucket=destination_bucket,
+            Key=destination_object_key,
+            CopySource=copy_source,
+            Config=UPLOAD_CONFIG,
         )
 
     @retry(exceptions=ObjectVerificationException, **CHECKSUM_RETRY_CONFIG)
